@@ -58,7 +58,7 @@ use PPIx::Regexp::Constant qw{
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.059';
+our $VERSION = '0.060';
 
 use constant ELEMENT_UNKNOWN => STRUCTURE_UNKNOWN;
 
@@ -222,6 +222,12 @@ sub last_element {
     return;
 }
 
+sub remove_insignificant {
+    my ( $self ) = @_;
+    return $self->__new(
+	map { $_->remove_insignificant() } $self->elements() );
+}
+
 =head2 start
 
  my $elem = $struct->start();
