@@ -40,7 +40,7 @@ use base qw{ PPIx::Regexp::Token };
 use Carp qw{ confess };
 use PPIx::Regexp::Constant qw{ @CARP_NOT };
 
-our $VERSION = '0.059';
+our $VERSION = '0.060';
 
 sub __new {
     my ( $class, $content, %arg ) = @_;
@@ -53,6 +53,10 @@ sub __new {
 
     $self->{error} = $arg{error};
 
+    $self->{explanation} = defined $arg{explanation} ?
+	$arg{explanation} :
+	$arg{error};
+
     return $self;
 }
 
@@ -60,6 +64,11 @@ sub __new {
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
 
+sub explain {
+    my ( $self ) = @_;
+    return $self->{explanation};
+}
+
 =head2 ordinal
 
 This method returns the results of the ord built-in on the content
@@ -82,6 +91,9 @@ sub __PPIX_ELEM__rebless {
 	$self->{error} = 'Unspecified error';
 	$rslt++;
     }
+    $self->{explanation} = defined $arg{explanation} ?
+	$arg{explanation} :
+	$arg{error};
     return $rslt;
 }
 
